"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.api = void 0;
const api_1 = require("@deep-foundation/hasura/api");
const client_1 = require("@deep-foundation/hasura/client");
const chai_1 = require("chai");
const bool_exp_1 = require("../imports/bool_exp");
const client_2 = require("../imports/client");
const promise_1 = require("../imports/promise");
exports.api = new api_1.HasuraApi({
    path: process.env.HASURA_PATH,
    ssl: !!+process.env.HASURA_SSL,
    secret: process.env.HASURA_SECRET,
});
const apolloClient = (0, client_1.generateApolloClient)({
    path: `${process.env.HASURA_PATH}/v1/graphql`,
    ssl: !!+process.env.HASURA_SSL,
    secret: process.env.HASURA_SECRET,
}, {
    ApolloClient: {
        defaultOptions: {
            watchQuery: {
                errorPolicy: 'all',
            },
        },
    },
});
const deep = new client_2.DeepClient({ apolloClient });
describe('bool_exp', () => {
    describe('value convertation', () => {
        it(`insert separately`, () => __awaiter(void 0, void 0, void 0, function* () {
            var _a, _b, _c, _d;
            const { data: [{ id: t1 }] } = yield deep.insert({
                type_id: yield deep.id('@deep-foundation/core', 'Any'),
            });
            const { data: [{ id: t2 }] } = yield deep.insert({
                type_id: yield deep.id('@deep-foundation/core', 'Any'),
            });
            const { data: [{ id: boolExpId }] } = yield deep.insert({
                type_id: yield deep.id('@deep-foundation/core', 'BoolExp'),
            });
            yield deep.insert({
                link_id: boolExpId,
                value: { id: { _eq: t1 } },
            }, { table: 'objects' });
            yield deep.await(boolExpId);
            yield (0, promise_1.delay)(2000);
            const { data: [{ value: sql }], error } = yield deep.select({
                link_id: { _eq: boolExpId },
            }, { table: 'bool_exp', returning: 'id link_id value' });
            const { data: d1 } = yield exports.api.sql((0, bool_exp_1.applyBoolExpToLink)(sql, t1));
            (0, chai_1.expect)(+((_b = (_a = d1 === null || d1 === void 0 ? void 0 : d1.result) === null || _a === void 0 ? void 0 : _a[1]) === null || _b === void 0 ? void 0 : _b[0])).to.equal(1);
            const { data: d2 } = yield exports.api.sql((0, bool_exp_1.applyBoolExpToLink)(sql, t2));
            (0, chai_1.expect)(+((_d = (_c = d2 === null || d2 === void 0 ? void 0 : d2.result) === null || _c === void 0 ? void 0 : _c[1]) === null || _d === void 0 ? void 0 : _d[0])).to.equal(0);
        }));
        it(`insert with link`, () => __awaiter(void 0, void 0, void 0, function* () {
            var _e, _f, _g, _h;
            const { data: [{ id: t1 }] } = yield deep.insert({
                type_id: yield deep.id('@deep-foundation/core', 'Any'),
            });
            const { data: [{ id: t2 }] } = yield deep.insert({
                type_id: yield deep.id('@deep-foundation/core', 'Any'),
            });
            const { data: [{ id: boolExpId }] } = yield deep.insert({
                type_id: yield deep.id('@deep-foundation/core', 'BoolExp'),
                object: { data: { value: { id: { _eq: t1 } } } },
            });
            yield deep.await(boolExpId);
            yield (0, promise_1.delay)(2000);
            const { data: [{ value: sql }], error } = yield deep.select({
                link_id: { _eq: boolExpId },
            }, { table: 'bool_exp', returning: 'id link_id value' });
            const { data: d1 } = yield exports.api.sql((0, bool_exp_1.applyBoolExpToLink)(sql, t1));
            (0, chai_1.expect)(+((_f = (_e = d1 === null || d1 === void 0 ? void 0 : d1.result) === null || _e === void 0 ? void 0 : _e[1]) === null || _f === void 0 ? void 0 : _f[0])).to.equal(1);
            const { data: d2 } = yield exports.api.sql((0, bool_exp_1.applyBoolExpToLink)(sql, t2));
            (0, chai_1.expect)(+((_h = (_g = d2 === null || d2 === void 0 ? void 0 : d2.result) === null || _g === void 0 ? void 0 : _g[1]) === null || _h === void 0 ? void 0 : _h[0])).to.equal(0);
        }));
        it(`update`, () => __awaiter(void 0, void 0, void 0, function* () {
            var _j, _k, _l, _m;
            const { data: [{ id: t1 }] } = yield deep.insert({
                type_id: yield deep.id('@deep-foundation/core', 'Any'),
            });
            const { data: [{ id: t2 }] } = yield deep.insert({
                type_id: yield deep.id('@deep-foundation/core', 'Any'),
            });
            const { data: [{ id: boolExpId }] } = yield deep.insert({
                type_id: yield deep.id('@deep-foundation/core', 'BoolExp'),
                object: { data: { value: { id: { _eq: t1 } } } },
            });
            yield deep.await(boolExpId);
            yield (0, promise_1.delay)(2000);
            yield deep.update({ link_id: { _eq: boolExpId } }, {
                value: { id: { _eq: t2 } },
            }, { table: 'objects' });
            yield deep.await(boolExpId);
            yield (0, promise_1.delay)(2000);
            const { data: [{ value: sql }], error } = yield deep.select({
                link_id: { _eq: boolExpId },
            }, { table: 'bool_exp', returning: 'id link_id value' });
            const { data: d1 } = yield exports.api.sql((0, bool_exp_1.applyBoolExpToLink)(sql, t1));
            (0, chai_1.expect)(+((_k = (_j = d1 === null || d1 === void 0 ? void 0 : d1.result) === null || _j === void 0 ? void 0 : _j[1]) === null || _k === void 0 ? void 0 : _k[0])).to.equal(0);
            const { data: d2 } = yield exports.api.sql((0, bool_exp_1.applyBoolExpToLink)(sql, t2));
            (0, chai_1.expect)(+((_m = (_l = d2 === null || d2 === void 0 ? void 0 : d2.result) === null || _l === void 0 ? void 0 : _l[1]) === null || _m === void 0 ? void 0 : _m[0])).to.equal(1);
        }));
        it(`delete`, () => __awaiter(void 0, void 0, void 0, function* () {
            const { data: [{ id: t1 }] } = yield deep.insert({
                type_id: yield deep.id('@deep-foundation/core', 'Any'),
            });
            const { data: [{ id: t2 }] } = yield deep.insert({
                type_id: yield deep.id('@deep-foundation/core', 'Any'),
            });
            const { data: [{ id: boolExpId }] } = yield deep.insert({
                type_id: yield deep.id('@deep-foundation/core', 'BoolExp'),
                object: { data: { value: { id: { _eq: t1 } } } },
            });
            yield deep.await(boolExpId);
            yield (0, promise_1.delay)(2000);
            yield deep.delete({ link_id: { _eq: boolExpId } }, { table: 'objects' });
            yield deep.await(boolExpId);
            yield (0, promise_1.delay)(2000);
            const { data, error } = yield deep.select({
                link_id: { _eq: boolExpId },
            }, { table: 'bool_exp', returning: 'id link_id value' });
            (0, chai_1.expect)(data).to.be.empty;
        }));
    });
});
//# sourceMappingURL=bool_exp.js.map